@@ -1,10 +1,10 @@
-import argparse
+from argparse import ArgumentParser
 
 __author__ = 'Kapustlo'
 
-__version__ = '1.2.1'
+__version__ = '2.0.0'
 
-parser = argparse.ArgumentParser(description='Build Django project')
+parser: ArgumentParser = ArgumentParser(description='Build Django project')
 
 parser.add_argument('name', metavar='name', help='Django project name')
 
